@@ -5,7 +5,6 @@ from django.utils.deprecation import MiddlewareMixin
 from django.urls import NoReverseMatch, reverse
 
 from .helpers import is_equal_or_sub_url, is_white_listed_url
-from .models import Tier
 from .app_settings import settings
 from .waffle_utils import should_redirect_non_authenticated
 
@@ -61,9 +60,11 @@ class TierMiddleware(MiddlewareMixin):
         try:
             organization_tier_getter_name = settings.organization_tier_getter_name()
             if organization_tier_getter_name:
+                # TODO: Refactor into a helper to get `TierInfo` directly within `edx-organizations` or LMS
                 tier = org.__getattribute__(organization_tier_getter_name)()
+                tier_info = tier.get_tier_info()
             else:
-                tier = org.tier
+                tier_info = org.tier.get_tier_info()
         except Exception:
             # If the organization for some reason does not have a tier assigned
             # fail silently. This should not happen. We should always automatically create
@@ -73,18 +74,17 @@ class TierMiddleware(MiddlewareMixin):
             return
 
         # Only display expiration warning for Trial tiers for now
-        request.session['DISPLAY_EXPIRATION_WARNING'] = ((tier.name == Tier.TIERS.TRIAL) and
-                                                         (not tier.tier_enforcement_exempt))
-        request.session['TIER_EXPIRES_IN'] = tier.time_til_tier_expires()
+        request.session['DISPLAY_EXPIRATION_WARNING'] = tier_info.should_show_expiration_warning()
+        request.session['TIER_EXPIRES_IN'] = tier_info.time_til_expiration()
         beeline.add_context_field("tiers.tier_expires_in", request.session['TIER_EXPIRES_IN'])
         # TODO: I'm not sure if we have to refresh the session info at this point somehow.
-        request.session['TIER_EXPIRED'] = tier.has_tier_expired()
+        request.session['TIER_EXPIRED'] = tier_info.has_subscription_ended()
         beeline.add_context_field("tiers.tier_expired", request.session['TIER_EXPIRED'])
         # TODO: We should use request.TIER_NAME instead of meddling the session, but being consistent for now
-        request.session['TIER_NAME'] = tier.name
-        beeline.add_context_field("tiers.tier_name", tier.name)
+        request.session['TIER_NAME'] = tier_info.tier
+        beeline.add_context_field("tiers.tier_name", tier_info.tier)
 
         # TODO: I'm not sure if we have to refresh the session info at this point somehow.
-        if tier.has_tier_expired():
+        if tier_info.has_subscription_ended():
             if expired_redirect_url and not is_white_listed_url(request.path):
                 return redirect(expired_redirect_url)
